#!/bin/sh

echo "Content-Type: text/html"
echo
echo "<pre>"

set -e

if [ "$(id -un)" != "www-data" ]; then
        echo "run this as user www-data only" >&2
        exit 1
fi

umask 0002

cd /osgeo/download/osgeo4w/v1
exec 2>>/tmp/osgeo4w-regen.log

if ! lockfile -l 600 .lock/regen.lock; then
	echo Locking failed
	exit 1
fi

trap "rm -f $PWD/.lock/regen.lock" EXIT

echo -n "start: " >&2
date >&2

echo "</pre>"
echo "<h1>Changes</h1>"

echo "<table border=1>"

for arch in x86 x86_64; do
	echo -n "$arch: " >&2
	date >&2

	echo "<tr><th>$arch</th><td><pre>"
	cat $arch/setup_test.ini >$arch/setup_test.ini.prev
	chmod -f -R a+r $arch/release || true
	echo -n "<font color=#ff0000>"
	./genini --arch=$arch --recursive --output=$arch/setup_test.ini $arch/release 2>&1 | tee -a /dev/stderr
	echo -n "</font>"
	bzip2 -c $arch/setup_test.ini >$arch/setup_test.ini.bz2

	./versions.pl "current $arch test packages" $arch/setup_test.ini >$arch/versions_test.html
	./htmldiff $arch/versions.html $arch/versions_test.html >$arch/versions_diff.html

	diff -u $arch/setup_test.ini.prev $arch/setup_test.ini && echo -n "(none)" || true
	echo "</pre></td></tr>"
done

# Compare x86 and x86_64
./htmldiff x86/versions_test.html x86_64/versions_test.html >versions_test-x86-x86_64.html

echo "</table>"

echo -n "end: " >&2
date >&2

echo "<br>"
echo '<a href="/cgi-bin/osgeo4w-promote-v1.sh">Promote changes...</a>'
